@@ -204,70 +204,70 @@ impl<'a> PLL_LDO_EN_W<'a> {
 }
 #[doc = "Lock Enable\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
-pub enum LOCK_EN_A {
+pub enum LOCK_ENABLE_A {
     #[doc = "0: `0`"]
     DISABLE = 0,
     #[doc = "1: `1`"]
     ENABLE = 1,
 }
-impl From<LOCK_EN_A> for bool {
+impl From<LOCK_ENABLE_A> for bool {
     #[inline(always)]
-    fn from(variant: LOCK_EN_A) -> Self {
+    fn from(variant: LOCK_ENABLE_A) -> Self {
         variant as u8 != 0
     }
 }
-#[doc = "Field `LOCK_EN` reader - Lock Enable"]
-pub struct LOCK_EN_R(crate::FieldReader<bool, LOCK_EN_A>);
-impl LOCK_EN_R {
+#[doc = "Field `LOCK_ENABLE` reader - Lock Enable"]
+pub struct LOCK_ENABLE_R(crate::FieldReader<bool, LOCK_ENABLE_A>);
+impl LOCK_ENABLE_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
-        LOCK_EN_R(crate::FieldReader::new(bits))
+        LOCK_ENABLE_R(crate::FieldReader::new(bits))
     }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
-    pub fn variant(&self) -> LOCK_EN_A {
+    pub fn variant(&self) -> LOCK_ENABLE_A {
         match self.bits {
-            false => LOCK_EN_A::DISABLE,
-            true => LOCK_EN_A::ENABLE,
+            false => LOCK_ENABLE_A::DISABLE,
+            true => LOCK_ENABLE_A::ENABLE,
         }
     }
     #[doc = "Checks if the value of the field is `DISABLE`"]
     #[inline(always)]
     pub fn is_disable(&self) -> bool {
-        **self == LOCK_EN_A::DISABLE
+        **self == LOCK_ENABLE_A::DISABLE
     }
     #[doc = "Checks if the value of the field is `ENABLE`"]
     #[inline(always)]
     pub fn is_enable(&self) -> bool {
-        **self == LOCK_EN_A::ENABLE
+        **self == LOCK_ENABLE_A::ENABLE
     }
 }
-impl core::ops::Deref for LOCK_EN_R {
-    type Target = crate::FieldReader<bool, LOCK_EN_A>;
+impl core::ops::Deref for LOCK_ENABLE_R {
+    type Target = crate::FieldReader<bool, LOCK_ENABLE_A>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
-#[doc = "Field `LOCK_EN` writer - Lock Enable"]
-pub struct LOCK_EN_W<'a> {
+#[doc = "Field `LOCK_ENABLE` writer - Lock Enable"]
+pub struct LOCK_ENABLE_W<'a> {
     w: &'a mut W,
 }
-impl<'a> LOCK_EN_W<'a> {
+impl<'a> LOCK_ENABLE_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
-    pub fn variant(self, variant: LOCK_EN_A) -> &'a mut W {
+    pub fn variant(self, variant: LOCK_ENABLE_A) -> &'a mut W {
         self.bit(variant.into())
     }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn disable(self) -> &'a mut W {
-        self.variant(LOCK_EN_A::DISABLE)
+        self.variant(LOCK_ENABLE_A::DISABLE)
     }
     #[doc = "`1`"]
     #[inline(always)]
     pub fn enable(self) -> &'a mut W {
-        self.variant(LOCK_EN_A::ENABLE)
+        self.variant(LOCK_ENABLE_A::ENABLE)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -291,7 +291,7 @@ impl<'a> LOCK_EN_W<'a> {
 pub enum LOCK_A {
     #[doc = "0: `0`"]
     UNLOCKED = 0,
-    #[doc = "1: It indicates that the PLL has been stable."]
+    #[doc = "1: `1`"]
     LOCKED = 1,
 }
 impl From<LOCK_A> for bool {
@@ -417,7 +417,7 @@ impl<'a> PLL_OUTPUT_GATE_W<'a> {
         self.w
     }
 }
-#[doc = "Field `PLL_LOCK_TIME` reader - PLL Lock Time\n\nThe bit indicates the step amplitude from one frequency to another."]
+#[doc = "Field `PLL_LOCK_TIME` reader - PLL Lock Time"]
 pub struct PLL_LOCK_TIME_R(crate::FieldReader<u8, u8>);
 impl PLL_LOCK_TIME_R {
     #[inline(always)]
@@ -432,7 +432,7 @@ impl core::ops::Deref for PLL_LOCK_TIME_R {
         &self.0
     }
 }
-#[doc = "Field `PLL_LOCK_TIME` writer - PLL Lock Time\n\nThe bit indicates the step amplitude from one frequency to another."]
+#[doc = "Field `PLL_LOCK_TIME` writer - PLL Lock Time"]
 pub struct PLL_LOCK_TIME_W<'a> {
     w: &'a mut W,
 }
@@ -444,7 +444,7 @@ impl<'a> PLL_LOCK_TIME_W<'a> {
         self.w
     }
 }
-#[doc = "Field `PLL_N` reader - PLL N\n\nN = PLL_N + 1\n\nPLL_N is from 0 to 254"]
+#[doc = "Field `PLL_N` reader - PLL N"]
 pub struct PLL_N_R(crate::FieldReader<u8, u8>);
 impl PLL_N_R {
     #[inline(always)]
@@ -459,7 +459,7 @@ impl core::ops::Deref for PLL_N_R {
         &self.0
     }
 }
-#[doc = "Field `PLL_N` writer - PLL N\n\nN = PLL_N + 1\n\nPLL_N is from 0 to 254"]
+#[doc = "Field `PLL_N` writer - PLL N"]
 pub struct PLL_N_W<'a> {
     w: &'a mut W,
 }
@@ -475,11 +475,11 @@ impl<'a> PLL_N_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 #[repr(u8)]
 pub enum PLL_UNLOCK_MDSEL_A {
-    #[doc = "0: 21 - 29 Clock Cycles"]
+    #[doc = "0: `0`"]
     CC_21_29 = 0,
-    #[doc = "1: 22 - 28 Clock Cycles"]
+    #[doc = "1: `1`"]
     CC_22_28 = 1,
-    #[doc = "2: 20 - 30 Clock Cycles"]
+    #[doc = "2: `10`"]
     CC_20_30 = 2,
 }
 impl From<PLL_UNLOCK_MDSEL_A> for u8 {
@@ -538,17 +538,17 @@ impl<'a> PLL_UNLOCK_MDSEL_W<'a> {
     pub fn variant(self, variant: PLL_UNLOCK_MDSEL_A) -> &'a mut W {
         unsafe { self.bits(variant.into()) }
     }
-    #[doc = "21 - 29 Clock Cycles"]
+    #[doc = "`0`"]
     #[inline(always)]
     pub fn cc_21_29(self) -> &'a mut W {
         self.variant(PLL_UNLOCK_MDSEL_A::CC_21_29)
     }
-    #[doc = "22 - 28 Clock Cycles"]
+    #[doc = "`1`"]
     #[inline(always)]
     pub fn cc_22_28(self) -> &'a mut W {
         self.variant(PLL_UNLOCK_MDSEL_A::CC_22_28)
     }
-    #[doc = "20 - 30 Clock Cycles"]
+    #[doc = "`10`"]
     #[inline(always)]
     pub fn cc_20_30(self) -> &'a mut W {
         self.variant(PLL_UNLOCK_MDSEL_A::CC_20_30)
@@ -563,9 +563,9 @@ impl<'a> PLL_UNLOCK_MDSEL_W<'a> {
 #[doc = "PLL Lock Level\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PLL_LOCK_MDSEL_A {
-    #[doc = "0: 24 - 26 Clock Cycles"]
+    #[doc = "0: `0`"]
     CC_24_26 = 0,
-    #[doc = "1: 23 - 27 Clock Cycles"]
+    #[doc = "1: `1`"]
     CC_23_27 = 1,
 }
 impl From<PLL_LOCK_MDSEL_A> for bool {
@@ -617,12 +617,12 @@ impl<'a> PLL_LOCK_MDSEL_W<'a> {
     pub fn variant(self, variant: PLL_LOCK_MDSEL_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "24 - 26 Clock Cycles"]
+    #[doc = "`0`"]
     #[inline(always)]
     pub fn cc_24_26(self) -> &'a mut W {
         self.variant(PLL_LOCK_MDSEL_A::CC_24_26)
     }
-    #[doc = "23 - 27 Clock Cycles"]
+    #[doc = "`1`"]
     #[inline(always)]
     pub fn cc_23_27(self) -> &'a mut W {
         self.variant(PLL_LOCK_MDSEL_A::CC_23_27)
@@ -644,7 +644,7 @@ impl<'a> PLL_LOCK_MDSEL_W<'a> {
         self.w
     }
 }
-#[doc = "Field `PLL_M` reader - PLL M\n\nM = PLL_FACTOR_M + 1\n\nPLL_FACTOR_M is from 0 to 3"]
+#[doc = "Field `PLL_M` reader - PLL M"]
 pub struct PLL_M_R(crate::FieldReader<u8, u8>);
 impl PLL_M_R {
     #[inline(always)]
@@ -659,7 +659,7 @@ impl core::ops::Deref for PLL_M_R {
         &self.0
     }
 }
-#[doc = "Field `PLL_M` writer - PLL M\n\nM = PLL_FACTOR_M + 1\n\nPLL_FACTOR_M is from 0 to 3"]
+#[doc = "Field `PLL_M` writer - PLL M"]
 pub struct PLL_M_W<'a> {
     w: &'a mut W,
 }
@@ -684,8 +684,8 @@ impl R {
     }
     #[doc = "Bit 29 - Lock Enable"]
     #[inline(always)]
-    pub fn lock_en(&self) -> LOCK_EN_R {
-        LOCK_EN_R::new(((self.bits >> 29) & 0x01) != 0)
+    pub fn lock_enable(&self) -> LOCK_ENABLE_R {
+        LOCK_ENABLE_R::new(((self.bits >> 29) & 0x01) != 0)
     }
     #[doc = "Bit 28 - PLL Lock Status"]
     #[inline(always)]
@@ -697,12 +697,12 @@ impl R {
     pub fn pll_output_gate(&self) -> PLL_OUTPUT_GATE_R {
         PLL_OUTPUT_GATE_R::new(((self.bits >> 27) & 0x01) != 0)
     }
-    #[doc = "Bits 24:26 - PLL Lock Time\n\nThe bit indicates the step amplitude from one frequency to another."]
+    #[doc = "Bits 24:26 - PLL Lock Time"]
     #[inline(always)]
     pub fn pll_lock_time(&self) -> PLL_LOCK_TIME_R {
         PLL_LOCK_TIME_R::new(((self.bits >> 24) & 0x07) as u8)
     }
-    #[doc = "Bits 8:15 - PLL N\n\nN = PLL_N + 1\n\nPLL_N is from 0 to 254"]
+    #[doc = "Bits 8:15 - PLL N"]
     #[inline(always)]
     pub fn pll_n(&self) -> PLL_N_R {
         PLL_N_R::new(((self.bits >> 8) & 0xff) as u8)
@@ -717,7 +717,7 @@ impl R {
     pub fn pll_lock_mdsel(&self) -> PLL_LOCK_MDSEL_R {
         PLL_LOCK_MDSEL_R::new(((self.bits >> 5) & 0x01) != 0)
     }
-    #[doc = "Bits 0:1 - PLL M\n\nM = PLL_FACTOR_M + 1\n\nPLL_FACTOR_M is from 0 to 3"]
+    #[doc = "Bits 0:1 - PLL M"]
     #[inline(always)]
     pub fn pll_m(&self) -> PLL_M_R {
         PLL_M_R::new((self.bits & 0x03) as u8)
@@ -736,20 +736,20 @@ impl W {
     }
     #[doc = "Bit 29 - Lock Enable"]
     #[inline(always)]
-    pub fn lock_en(&mut self) -> LOCK_EN_W {
-        LOCK_EN_W { w: self }
+    pub fn lock_enable(&mut self) -> LOCK_ENABLE_W {
+        LOCK_ENABLE_W { w: self }
     }
     #[doc = "Bit 27 - PLL Output Gating Enable"]
     #[inline(always)]
     pub fn pll_output_gate(&mut self) -> PLL_OUTPUT_GATE_W {
         PLL_OUTPUT_GATE_W { w: self }
     }
-    #[doc = "Bits 24:26 - PLL Lock Time\n\nThe bit indicates the step amplitude from one frequency to another."]
+    #[doc = "Bits 24:26 - PLL Lock Time"]
     #[inline(always)]
     pub fn pll_lock_time(&mut self) -> PLL_LOCK_TIME_W {
         PLL_LOCK_TIME_W { w: self }
     }
-    #[doc = "Bits 8:15 - PLL N\n\nN = PLL_N + 1\n\nPLL_N is from 0 to 254"]
+    #[doc = "Bits 8:15 - PLL N"]
     #[inline(always)]
     pub fn pll_n(&mut self) -> PLL_N_W {
         PLL_N_W { w: self }
@@ -764,7 +764,7 @@ impl W {
     pub fn pll_lock_mdsel(&mut self) -> PLL_LOCK_MDSEL_W {
         PLL_LOCK_MDSEL_W { w: self }
     }
-    #[doc = "Bits 0:1 - PLL M\n\nM = PLL_FACTOR_M + 1\n\nPLL_FACTOR_M is from 0 to 3"]
+    #[doc = "Bits 0:1 - PLL M"]
     #[inline(always)]
     pub fn pll_m(&mut self) -> PLL_M_W {
         PLL_M_W { w: self }
